@@ -117,6 +117,7 @@ copy_file (const char *realfilename1, const char *realfilename2)
     if (sourcefile == NULL)
 	{
 		fprintf (stderr, "can't open %s !\n", realfilename1);
+		fclose (targetfile);
 		return (-2);
 	}
 	while ((c = getc (sourcefile)) != EOF)
@@ -555,7 +556,6 @@ my_scandir (char *dirname, struct direntry *(*namelist[]),
 	int           n;						   /* Count of nl used so far */
 	int           sizenl;					   /* Number of entries in nl array */
 	int           j;
-	size_t        realsize;
 	char         *filename;					   /* For building filename to pass to stat */
 	char         *p;						   /* Place where filename starts */
 	struct stat   buf;
@@ -604,32 +604,17 @@ my_scandir (char *dirname, struct direntry *(*namelist[]),
 				}
 				nl = nnl;
 			}
-			realsize = offsetof (struct direntry, d_name)+strlen (e->d_name) + 1;
-			nl[n] = (struct direntry *)safemalloc (realsize);
-			if (nl[n] == NULL)
-			{
-				for (j = 0; j < n; j++)
-					free (nl[j]);
-				free (nl);
-				free (filename);
-				closedir (d);
-				return -1;
-			}
 			/* Fill in the fields using stat() */
 			strcpy (p, e->d_name);
-			if (stat (filename, &buf) == -1)
-			{
-				for (j = 0; j <= n; j++)
-					free (nl[j]);
-				free (nl);
-				free (filename);
-				closedir (d);
-				return -1;
+			if (stat (filename, &buf) != -1)
+			{	
+				size_t realsize = offsetof (struct direntry, d_name)+strlen (e->d_name) + 1;
+				nl[n] = (struct direntry *)safemalloc (realsize);
+				nl[n]->d_mode = buf.st_mode;
+				nl[n]->d_mtime = buf.st_mtime;
+				strcpy (nl[n]->d_name, e->d_name);
+				n++;
 			}
-			nl[n]->d_mode = buf.st_mode;
-			nl[n]->d_mtime = buf.st_mtime;
-			strcpy (nl[n]->d_name, e->d_name);
-			n++;
 		}
 	}
 	free (filename);
