@@ -82,6 +82,7 @@ extern struct SyntaxDef		 WharfLookSyntax;
 extern struct SyntaxDef		 WharfPrivateSyntax;
 extern struct SyntaxDef 	 WharfFolderSyntax;
 extern struct SyntaxDef 	 WharfSyntax;
+extern struct SyntaxDef      WinCommandSyntax; 
 extern struct SyntaxDef      WinListSyntax;
 extern struct SyntaxDef      WinListPrivateSyntax;
 extern struct SyntaxDef      WinListLookSyntax;
@@ -1411,6 +1412,9 @@ int WriteWharfOptions (const char *filename, char *myname,
 #define LOOK_SeparateButtonTitle_ID				(LOOK_SUPPORTED_ID_START+38)
 #define LOOK_RubberBand_ID						(LOOK_SUPPORTED_ID_START+39)					  
 #define LOOK_WindowStyle_ID_START				(LOOK_SUPPORTED_ID_START+40)
+
+#define LOOK_IconsGrowVertically_ID                             (LOOK_SUPPORTED_ID_START+41)
+
 #define LOOK_DefaultStyle_ID					LOOK_WindowStyle_ID_START						  
 #define LOOK_FWindowStyle_ID					(LOOK_WindowStyle_ID_START+1)						  
 #define LOOK_UWindowStyle_ID					(LOOK_WindowStyle_ID_START+2)						  
@@ -1839,6 +1843,9 @@ ColorConfig *ASColorScheme2ColorConfig( ASColorScheme *cs );
 ASColorScheme *ColorConfig2ASColorScheme( ColorConfig *config );
 
 void LoadColorScheme();                        /* high level easy to use function */
+void translate_gtkrc_template_file( const char *template_fname, const char *output_fname );
+void UpdateGtkRC();
+
 
 
 /***************************************************************************/
