@@ -1490,7 +1490,7 @@ free_glyph_map( ASGlyphMap *map, Bool reusable )
 {
     if( map )
     {
-		if( map->glyphs );
+		if( map->glyphs )
 	        free( map->glyphs );
         if( !reusable )
             free( map );
