@@ -138,9 +138,36 @@ as_image_loader_func as_image_file_loaders[ASIT_Unknown] =
 	tiff2ASImage,
 	xml2ASImage ,
 	NULL,
+	tga2ASImage,
+	NULL,
 	NULL,
 	NULL
 };
+
+const char *as_image_file_type_names[ASIT_Unknown+1] =
+{
+	"XPM" ,
+	"Z-compressed XPM" ,
+	"GZ-compressed XPM" ,
+	"PNG" ,
+	"JPEG",
+	"GIMP Xcf" ,
+	"PPM" ,
+	"PNM" ,
+	"MS Windows Bitmap" ,
+	"MS Windows Icon" ,
+	"MS Windows Cursor" ,
+	"GIF" ,
+	"TIFF",
+	"AfterStep XML" ,
+	"XBM",
+	"Targa",
+	"PCX",
+	"HTML",
+	"XML",
+	"Unknown"
+};
+
  
 ASImage *
 file2ASImage_extra( const char *file, ASImageImportParams *iparams )
@@ -329,6 +356,82 @@ get_asimage( ASImageManager* imageman, const char *file, ASFlagType what, unsign
 	return im;
 }
 
+ASImageListEntry * 
+ref_asimage_list_entry( ASImageListEntry *entry )
+{
+	if( entry ) 
+	{
+		if( IS_ASIMAGE_LIST_ENTRY(entry) )
+			++(entry->ref_count);
+		else
+			entry = NULL ; 
+	}
+	return entry;
+}
+	 
+ASImageListEntry *
+unref_asimage_list_entry( ASImageListEntry *entry )
+{
+	if( entry ) 
+	{	
+		if( IS_ASIMAGE_LIST_ENTRY(entry) )
+		{
+			--(entry->ref_count);
+			if( entry->ref_count  <= 0 )
+			{
+				ASImageListEntry *prev = entry->prev ; 
+				ASImageListEntry *next = entry->next ; 
+				if( !IS_ASIMAGE_LIST_ENTRY(prev) )
+					prev = NULL ; 
+				if( !IS_ASIMAGE_LIST_ENTRY(next) )
+					next = NULL ; 
+				if( prev ) 
+					prev->next = next ; 
+				if( next ) 
+					next->prev = prev ; 
+
+				if( entry->preview ) 
+					safe_asimage_destroy( entry->preview );
+				if( entry->name )
+					free( entry->name );
+				if( entry->fullfilename )
+					free( entry->fullfilename );
+				memset( entry, 0x00, sizeof(ASImageListEntry));
+				free( entry );
+				entry = NULL ; 
+			}	 
+		}else
+			entry = NULL ;
+	}
+	return entry;
+}	 
+
+ASImageListEntry *
+create_asimage_list_entry()
+{
+	ASImageListEntry *entry = safecalloc( 1, sizeof(ASImageListEntry));
+	entry->ref_count = 1 ; 
+	entry->magic = MAGIC_ASIMAGE_LIST_ENTRY ; 
+	return entry;
+}
+
+void
+destroy_asimage_list( ASImageListEntry **plist )
+{
+	if( plist )
+	{		   
+		ASImageListEntry *curr = *plist ;
+		while( IS_ASIMAGE_LIST_ENTRY(curr) )
+		{	
+			ASImageListEntry *to_delete = curr ; 
+			curr = curr->next ;
+		 	unref_asimage_list_entry( to_delete );
+		}
+		*plist = NULL ;
+	}
+}
+
+
 ASImageListEntry *
 get_asimage_list( ASVisual *asv, const char *dir,
 	              ASFlagType preview_type, double gamma,
@@ -366,9 +469,10 @@ get_asimage_list( ASVisual *asv, const char *dir,
 					file_type = ASIT_Unknown ;
 
 				++count ;
-				*curr = safecalloc( 1, sizeof(ASImageListEntry) );
+				*curr = create_asimage_list_entry();
 				if( last )
 					last->next = *curr ;
+				(*curr)->prev = last ;
 				last = *curr ;
 				curr = &(last->next);
 
@@ -435,6 +539,23 @@ get_asimage_list( ASVisual *asv, const char *dir,
 	return im_list;
 }
 
+char *format_asimage_list_entry_details( ASImageListEntry *entry, Bool vertical )
+{
+	char *details_text ;
+
+	if( entry ) 
+	{	
+		int type = (entry->type>ASIT_Unknown)?ASIT_Unknown:entry->type ; 
+		details_text = safemalloc(128);
+		if( entry->preview ) 
+			sprintf( details_text, vertical?"File type: %s\nSize %dx%d":"File type: %s; Size %dx%d", as_image_file_type_names[type], entry->preview->width, entry->preview->height ); 	  
+		else 
+			sprintf( details_text, "File type: %s", as_image_file_type_names[type]);
+	}else
+		details_text = mystrdup("");		   
+	return details_text;
+}	 
+
 
 /***********************************************************************************/
 /* Some helper functions :                                                         */
@@ -459,6 +580,10 @@ locate_image_file( const char *file, char **paths )
 				register int i = 0;
 				do
 				{
+					if( i > 0 ) 
+					{	
+						show_progress( "looking for image \"%s\" in path [%s]", file, paths[i] );
+					}		
 					realfilename = find_file( file, paths[i], R_OK );
 				}while( realfilename == NULL && paths[i++] != NULL );
 			}
@@ -490,7 +615,10 @@ check_image_type( const char *realfilename )
 	FILE *fp ;
 	ASImageFileTypes type = ASIT_Unknown ;
 	/* lets check if we have compressed xpm file : */
-	if( filename_len > 7 && mystrncasecmp( realfilename+filename_len-7, ".xpm.gz", 7 ) == 0 )
+	if( filename_len > 5 && (mystrncasecmp( realfilename+filename_len-5, ".html", 5 ) == 0 || 
+							 mystrncasecmp( realfilename+filename_len-4, ".htm", 4 ) == 0 ))
+		type = ASIT_HTML;
+	else if( filename_len > 7 && mystrncasecmp( realfilename+filename_len-7, ".xpm.gz", 7 ) == 0 )
 		type = ASIT_GZCompressedXpm;
 	else if( filename_len > 6 && mystrncasecmp( realfilename+filename_len-6, ".xpm.Z", 6 ) == 0 )
 		type = ASIT_ZCompressedXpm ;
@@ -527,6 +655,11 @@ check_image_type( const char *realfilename )
 						 mystrncasecmp(realfilename+filename_len-4, ".ICO", 4)==0) )
 				type = ASIT_Cur;
 		}
+		if( type == ASIT_Unknown && bytes_in  > 6 )
+		{
+			if( mystrncasecmp( head, "<HTML>", 6 ) == 0 )
+				type = ASIT_HTML;	
+		}	 
 		if( type == ASIT_Unknown && bytes_in  > 8 )
 		{
 			if( strncmp((char *)&(head[0]), XCF_SIGNATURE, (size_t) XCF_SIGNATURE_LEN) == 0)
@@ -538,36 +671,55 @@ check_image_type( const char *realfilename )
 				type = ASIT_Xbm;
 			else
 			{/* the nastiest check - for XML files : */
-				register int i ;
+				int i ;
 
 				type = ASIT_XMLScript ;
+				for( i = 0 ; i < bytes_in ; ++i ) if( !isspace(head[i]) ) break;
 				while( bytes_in > 0 && type == ASIT_XMLScript )
 				{
-					for( i = 0 ; i < bytes_in ; ++i ) if( !isspace(head[i]) ) break;
 					if( i >= bytes_in )
+					{	
 						bytes_in = fread( &(head[0]), sizeof(CARD8), FILE_HEADER_SIZE, fp );
+						for( i = 0 ; i < bytes_in ; ++i ) if( !isspace(head[i]) ) break;
+					}
 					else if( head[i] != '<' )
 						type = ASIT_Unknown ;
-					else
-						break ;
-				}
-				while( bytes_in > 0 && type == ASIT_XMLScript )
-				{
-					for( i = 0 ; i < bytes_in ; ++i )
-						if( !isspace(head[i]) )
+					else if( mystrncasecmp( &(head[i]), "<!DOCTYPE ", 10 ) == 0 ) 
+					{	
+						type = ASIT_XML ;
+						for( i += 9 ; i < bytes_in ; ++i ) if( !isspace(head[i]) ) break;
+						if( i < bytes_in ) 
 						{
-							if( !isprint(head[i]) )
+					 		if( mystrncasecmp( &(head[i]), "afterstep-image-xml", 19 ) == 0 ) 			
 							{
-								type = ASIT_Unknown ;
-								break ;
-							}else if( head[i] == '>' )
+								i += 19 ;	  
+								type = ASIT_XMLScript ;
+							}
+						}	 
+					}else
+					{
+						while( bytes_in > 0 && type == ASIT_XMLScript )
+						{
+							while( ++i < bytes_in )
+								if( !isspace(head[i]) )
+								{
+									if( !isprint(head[i]) )
+									{
+										type = ASIT_Unknown ;
+										break ;
+									}else if( head[i] == '>' )
+										break ;
+								}
+
+							if( i >= bytes_in )
+							{	
+								bytes_in = fread( &(head[0]), sizeof(CARD8), FILE_HEADER_SIZE, fp );
+								i = 0 ; 
+							}else
 								break ;
 						}
-
-					if( i >= bytes_in )
-						bytes_in = fread( &(head[0]), sizeof(CARD8), FILE_HEADER_SIZE, fp );
-					else
-						break ;
+						break;
+					}	
 				}
 			}
 		}
@@ -813,7 +965,7 @@ png2ASImage( const char * path, ASImageImportParams *params )
 						raw2scanline( row_pointers[y], &buf, NULL, buf.width, grayscale, do_alpha );
 						im->channels[IC_RED][y] = store_data( NULL, (CARD8*)buf.red, buf.width*4, rgb_flags, 0);
 					}else
-						im->channels[IC_RED][y] = store_data( NULL, row_pointers[y], buf.width, rgb_flags, 0);
+						im->channels[IC_RED][y] = store_data( NULL, row_pointers[y], im->width, rgb_flags, 0);
 					
 					if( grayscale ) 
 					{	
@@ -1770,3 +1922,222 @@ xml2ASImage( const char *path, ASImageImportParams *params )
 	SHOW_TIME("image loading",started);
 	return im ;
 }
+/*************************************************************************/
+/* Targa Image format - some stuff borrowed from the GIMP.
+ *************************************************************************/
+typedef struct ASTGAHeader
+{
+	CARD8 IDLength ;
+	CARD8 ColorMapType;
+#define TGA_NoImageData			0
+#define TGA_ColormappedImage	1
+#define TGA_TrueColorImage		2
+#define TGA_BWImage				3
+#define TGA_RLEColormappedImage		9
+#define TGA_RLETrueColorImage		10
+#define TGA_RLEBWImage				11
+	CARD8 ImageType;
+	struct 
+	{
+		CARD16 FirstEntryIndex ;
+		CARD16 ColorMapLength ;  /* number of entries */ 
+		CARD8  ColorMapEntrySize ;  /* number of bits per entry */ 
+	}ColormapSpec;
+	struct
+	{		
+		CARD16 XOrigin;
+		CARD16 YOrigin;
+		CARD16 Width;
+		CARD16 Height;
+		CARD8  Depth;
+#define TGA_LeftToRight		(0x01<<4)
+#define TGA_TopToBottom		(0x01<<5)
+		CARD8  Descriptor;
+	}ImageSpec;
+
+}ASTGAHeader;
+
+typedef struct ASTGAColorMap
+{
+	int bytes_per_entry;
+	int bytes_total ; 
+	CARD8 *data ; 
+}ASTGAColorMap;
+
+typedef struct ASTGAImageData
+{
+	int bytes_per_pixel;
+	int image_size;
+	int bytes_total ; 
+	CARD8 *data ; 
+}ASTGAImageData;
+
+static Bool load_tga_colormapped(FILE *infile, ASTGAHeader *tga, ASTGAColorMap *cmap, ASScanline *buf, CARD8 *read_buf, CARD8 *gamma_table )
+{
+		
+	return True;
+}
+
+static Bool load_tga_truecolor(FILE *infile, ASTGAHeader *tga, ASTGAColorMap *cmap, ASScanline *buf, CARD8 *read_buf, CARD8 *gamma_table )
+{
+	CARD32 *a = buf->alpha ;
+	CARD32 *r = buf->red ;
+	CARD32 *g = buf->green ;
+	CARD32 *b = buf->blue ;
+	int bpp = (tga->ImageSpec.Depth+7)/8;
+	int bpl = buf->width*bpp;
+	if( fread( read_buf, 1, bpl, infile ) != bpl ) 		   
+		return False;
+	if( bpp == 3 ) 
+	{	
+		int i;
+		if( gamma_table )
+			for( i = 0 ; i < buf->width ; ++i ) 
+			{
+				b[i] = gamma_table[*(read_buf++)];	
+				g[i] = gamma_table[*(read_buf++)];	  
+				r[i] = gamma_table[*(read_buf++)];	  
+			}	 
+		else
+			for( i = 0 ; i < buf->width ; ++i ) 
+			{
+				b[i] = *(read_buf++);	
+				g[i] = *(read_buf++);	  
+				r[i] = *(read_buf++);	  
+			}	 
+		set_flags( buf->flags, SCL_DO_RED|SCL_DO_GREEN|SCL_DO_BLUE );
+	}else if( bpp == 4 )
+	{
+		int i;
+		for( i = 0 ; i < buf->width ; ++i ) 
+		{
+			b[i] = *(read_buf++);	
+			g[i] = *(read_buf++);	  
+			r[i] = *(read_buf++);	  
+			a[i] = *(read_buf++);	  
+		}	 
+		set_flags( buf->flags, SCL_DO_RED|SCL_DO_GREEN|SCL_DO_BLUE|SCL_DO_ALPHA );
+	}	 
+
+	return True;
+}
+
+static Bool load_tga_bw(FILE *infile, ASTGAHeader *tga, ASTGAColorMap *cmap, ASScanline *buf, CARD8 *read_buf, CARD8 *gamma_table )
+{
+		
+	return True;
+}
+
+static Bool load_tga_rle_colormapped(FILE *infile, ASTGAHeader *tga, ASTGAColorMap *cmap, ASScanline *buf, CARD8 *read_buf, CARD8 *gamma_table )
+{
+		
+	return True;
+}
+
+static Bool load_tga_rle_truecolor(FILE *infile, ASTGAHeader *tga, ASTGAColorMap *cmap, ASScanline *buf, CARD8 *read_buf, CARD8 *gamma_table )
+{
+		
+	return True;
+}
+
+static Bool load_tga_rle_bw(FILE *infile, ASTGAHeader *tga, ASTGAColorMap *cmap, ASScanline *buf, CARD8 *read_buf, CARD8 *gamma_table )
+{
+		
+	return True;
+}
+
+
+
+ASImage *
+tga2ASImage( const char * path, ASImageImportParams *params )
+{
+	ASImage *im = NULL ;
+	/* More stuff */
+	FILE         *infile;					   /* source file */
+	ASTGAHeader   tga;
+	ASTGAColorMap *cmap = NULL ;
+	int width = 1, height = 1;
+	START_TIME(started);
+
+
+	if ((infile = open_image_file(path)) == NULL)
+		return NULL;
+	if( fread( &tga, 1, 3, infile ) == 3 ) 
+	if( fread( &tga.ColormapSpec, 1, 5, infile ) == 5 ) 
+	if( fread( &tga.ImageSpec, 1, 10, infile ) == 10 ) 
+	{
+		Bool success = True ;
+		Bool (*load_row_func)(FILE *infile, ASTGAHeader *tga, ASTGAColorMap *cmap, ASScanline *buf, CARD8 *read_buf, CARD8 *gamma_table );
+
+		if( tga.IDLength > 0 ) 
+			success = (fseek( infile, tga.IDLength, SEEK_CUR )==0);
+		if( success && tga.ColorMapType != 0 ) 
+		{
+			cmap = safecalloc( 1, sizeof(ASTGAColorMap));
+			cmap->bytes_per_entry = (tga.ColormapSpec.ColorMapEntrySize+7)/8;
+			cmap->bytes_total = cmap->bytes_per_entry*tga.ColormapSpec.ColorMapLength; 
+			cmap->data = safemalloc( cmap->bytes_total);
+			success = ( fread( cmap->data, 1, cmap->bytes_total, infile ) == cmap->bytes_total );
+		}else if( tga.ImageSpec.Depth != 24 && tga.ImageSpec.Depth != 32 )
+			success = False ;
+	 
+		if( success ) 
+		{
+			success = False;
+			if( tga.ImageType != TGA_NoImageData )
+			{	
+				width = tga.ImageSpec.Width ; 
+				height = tga.ImageSpec.Height ; 
+				if( width < MAX_IMPORT_IMAGE_SIZE && height < MAX_IMPORT_IMAGE_SIZE )
+					success = True;
+			}
+		}
+		switch( tga.ImageType ) 
+		{
+			case TGA_ColormappedImage	:load_row_func = load_tga_colormapped ; break ;
+			case TGA_TrueColorImage		:load_row_func = load_tga_truecolor ; break ;
+			case TGA_BWImage			:load_row_func = load_tga_bw ; break ;
+			case TGA_RLEColormappedImage:load_row_func = load_tga_rle_colormapped ; break ;
+			case TGA_RLETrueColorImage	:load_row_func = load_tga_rle_truecolor ; break ;
+			case TGA_RLEBWImage			:load_row_func = load_tga_rle_bw ; break ;
+			default:
+				load_row_func = NULL ;
+		}	 
+		
+		if( success && load_row_func != NULL ) 
+		{	
+			ASImageOutput  *imout ;
+			im = create_asimage( width, height, params->compression );
+			if((imout = start_image_output( NULL, im, ASA_ASImage, 0, ASIMAGE_QUALITY_DEFAULT)) == NULL )
+			{
+        		destroy_asimage( &im );
+				success = False;
+			}else
+			{	
+				ASScanline    buf;
+				int y ;
+				CARD8 *read_buf = safemalloc( width*4*2 ); 
+				prepare_scanline( im->width, 0, &buf, True );
+				if( !get_flags( tga.ImageSpec.Descriptor, TGA_TopToBottom ) )			
+					toggle_image_output_direction( imout );
+				for( y = 0 ; y < height ; ++y ) 
+				{	
+					if( !load_row_func( infile, &tga, cmap, &buf, read_buf, params->gamma_table ) )
+						break;
+					imout->output_image_scanline( imout, &buf, 1);
+				}
+				stop_image_output( &imout );
+				free_scanline( &buf, True );
+				free( read_buf );
+			}   
+		}	  
+	}	 
+	if( im == NULL )
+		show_error( "invalid or unsupported TGA format in image file \"%s\"", path );
+
+	fclose( infile );
+	SHOW_TIME("image loading",started);
+	return im ;
+}
+
+
