@@ -141,8 +141,8 @@ parse_func (const char *text, FunctionData * data, int quiet)
 			} else if (isdigit (*ptr))
 			{
 				int           count;
-				char          unit;
-				int           val;
+				char          unit = '\0';
+				int           val = 0;
 
 				for (count = 1; isdigit (*(ptr + count)); count++);
 				if (*(ptr + count) != '\0' && !isspace (*(ptr + count)))
@@ -393,19 +393,21 @@ void
 decode_func_units (FunctionData * data)
 {
     register int  i;
+#if 0
     int defaults[MAX_FUNC_ARGS];
 
 	defaults[0] = ASDefaultScrWidth;
 	defaults[1] = ASDefaultScrHeight;
+#endif
 	for (i = 0; i < MAX_FUNC_ARGS; i++)
 		switch (data->unit[i])
 		{
 		 case 'p':
 		 case 'P':
-			 data->unit_val[i] = 100;
+			 data->unit_val[i] = 1;
 			 break;
 		 default:
-             data->unit_val[i] = defaults[i];
+             data->unit_val[i] = 0/*defaults[i]*/;
 		}
 }
 
@@ -647,7 +649,7 @@ check_availability( MenuDataItem *mdi )
     clear_flags( mdi->flags, MD_Disabled );
 #ifndef NO_AVAILABILITYCHECK
 LOCAL_DEBUG_OUT( "checking availability for \"%s\"", mdi->fdata->name?mdi->fdata->name:"nameless" );
-    if ( IsSwallowFunc(mdi->fdata->func) || IsExecFunc(mdi->fdata->func) )
+    if ( mdi->fdata->func!= F_ExecInTerm && (IsSwallowFunc(mdi->fdata->func) || IsExecFunc(mdi->fdata->func)) )
     {
 LOCAL_DEBUG_OUT( "now really checking availability for \"%s\"", mdi->fdata->name?mdi->fdata->name:"nameless" );
         if (!is_executable_in_path (mdi->fdata->text))
