@@ -37,7 +37,7 @@ init_ashints (ASHints * hints)
 {
 	if (hints)
 	{										   /* some defaults to start with : */
-		hints->flags = AS_Gravity | AS_AcceptsFocus | AS_Titlebar | AS_Handles | AS_Border;
+		hints->flags = AS_Gravity | AS_AcceptsFocus | AS_Titlebar | AS_IconTitle | AS_Handles | AS_Border;
         /* can't gracefully close the window if it does not support WM_DELETE_WINDOW */
         hints->function_mask = ~(AS_FuncClose|AS_FuncPinMenu);
         hints->gravity = NorthWestGravity;
@@ -193,7 +193,7 @@ merge_command_line (ASHints * clean, ASStatusHints * status, ASRawHints * raw)
 }
 
 void
-check_hints_sanity (ScreenInfo * scr, ASHints * clean)
+check_hints_sanity (ScreenInfo * scr, ASHints * clean, ASStatusHints * status, Window client)
 {
 	if (clean)
 	{
@@ -220,6 +220,20 @@ check_hints_sanity (ScreenInfo * scr, ASHints * clean)
 			if (clean->icon_file == NULL && clean->icon.pixmap == None)
 				clear_flags (clean->flags, AS_Icon);
 
+		if( status && status->width <= 2 && status->height <= 2 ) 
+		{
+			if( clean->res_class && strcasecmp( clean->res_class, "DockApp" ) == 0 )
+				set_flags( clean->flags, AS_WMDockApp ); 	   
+		}	 
+			
+		if( clean->icon.window == client ) 
+		{
+			clean->icon.window = None ; 
+			clear_flags( clean->function_mask, AS_FuncMinimize );
+			clear_flags( clean->flags, AS_ClientIcon );
+		}	 
+
+
 		if (clean->frame_name == NULL)
 			clear_flags (clean->flags, AS_Frame);
         if (clean->windowbox_name == NULL)
@@ -261,7 +275,7 @@ check_status_sanity (ScreenInfo * scr, ASStatusHints * status)
 /* Hints merging functions : */
 ASHints      *
 merge_hints (ASRawHints * raw, ASDatabase * db, ASStatusHints * status,
-			 ASSupportedHints * list, ASFlagType what, ASHints * reusable_memory)
+			 ASSupportedHints * list, ASFlagType what, ASHints * reusable_memory, Window client)
 {
 	ASHints      *clean = NULL;
 	ASDatabaseRecord db_rec, *pdb_rec;
@@ -273,7 +287,7 @@ merge_hints (ASRawHints * raw, ASDatabase * db, ASStatusHints * status,
 	if ((clean = reusable_memory) == NULL)
 		clean = (ASHints *) safecalloc (1, sizeof (ASHints));
 	else
-		memset (reusable_memory, 0x00, sizeof (ASHints));
+		memset (clean, 0x00, sizeof (ASHints));
 	if (status)
 		memset (status, 0x00, sizeof (ASStatusHints));
 
@@ -330,7 +344,7 @@ merge_hints (ASRawHints * raw, ASDatabase * db, ASStatusHints * status,
 	if (get_flags (what, HINT_STARTUP) )
 		merge_command_line (clean, status, raw);
 
-	check_hints_sanity (raw->scr, clean);
+	check_hints_sanity (raw->scr, clean, status, client);
 	check_status_sanity (raw->scr, status);
 
 	/* this is needed so if user changes the list of supported hints -
@@ -358,7 +372,7 @@ update_protocols (ScreenInfo * scr, Window w, ASSupportedHints * list, ASFlagTyp
 
 	if (collect_hints (scr, w, HINT_PROTOCOL, &raw) != NULL)
 	{
-		if (merge_hints (&raw, NULL, NULL, list, HINT_PROTOCOL, &clean) != NULL)
+		if (merge_hints (&raw, NULL, NULL, list, HINT_PROTOCOL, &clean, w) != NULL)
 		{
 			if (pprots)
 				if ((changed = (*pprots != clean.protocols)))
@@ -388,7 +402,7 @@ update_colormaps (ScreenInfo * scr, Window w, ASSupportedHints * list, CARD32 **
 
 	if (collect_hints (scr, w, HINT_COLORMAP, &raw) != NULL)
 	{
-		if (merge_hints (&raw, NULL, NULL, list, HINT_COLORMAP, &clean) != NULL)
+		if (merge_hints (&raw, NULL, NULL, list, HINT_COLORMAP, &clean, w) != NULL)
 		{
 			old_win = *pcmap_windows;
 			new_win = clean.cmap_windows;
@@ -443,14 +457,16 @@ add_name_to_list (char **list, char *name, unsigned char *encoding_list, unsigne
 		return -1;
 	}
 
+#if 0	
 	for (; i > 0; i--)
 	{
 		list[i] = list[i - 1];
 		encoding_list[i] = encoding_list[i-1] ;
 	}
-	list[0] = name;
-	encoding_list[0] = encoding ;
-	return 0;
+#endif
+	list[i] = name;
+	encoding_list[i] = encoding ;
+	return i;
 }
 
 static int
@@ -478,6 +494,13 @@ merge_icccm_hints (ASHints * clean, ASRawHints * raw,
 		return;
 	if (get_flags (what, HINT_NAME))
 	{										   /* adding all the possible window names in order of increasing importance */
+		if (raw->wm_name)
+			add_name_to_list (clean->names, text_property2string (raw->wm_name), clean->names_encoding, AS_Text_ASCII);
+		if (raw->wm_icon_name)
+		{
+			clean->icon_name_idx = add_name_to_list (clean->names, text_property2string (raw->wm_icon_name), clean->names_encoding, AS_Text_ASCII);
+			clean->icon_name     = (clean->icon_name_idx < 0 )?NULL:clean->names[clean->icon_name_idx];
+		}
 		if (raw->wm_class)
 		{
 			if (raw->wm_class->res_class)
@@ -491,14 +514,6 @@ merge_icccm_hints (ASHints * clean, ASRawHints * raw,
 				clean->res_name = (clean->res_name_idx < 0 )?NULL:clean->names[clean->res_name_idx];
 			}
 		}
-		if (raw->wm_icon_name)
-		{
-			clean->icon_name_idx = add_name_to_list (clean->names, text_property2string (raw->wm_icon_name), clean->names_encoding, AS_Text_ASCII);
-			clean->icon_name     = (clean->icon_name_idx < 0 )?NULL:clean->names[clean->icon_name_idx];
-		}
-
-		if (raw->wm_name)
-			add_name_to_list (clean->names, text_property2string (raw->wm_name), clean->names_encoding, AS_Text_ASCII);
 	}
 
 	if (get_flags (what, HINT_STARTUP) && status != NULL)
@@ -561,7 +576,8 @@ merge_icccm_hints (ASHints * clean, ASRawHints * raw,
 				clean->icon.window = wmh->icon_window;
 				set_flags (clean->flags, AS_ClientIcon);
 				clear_flags (clean->flags, AS_ClientIconPixmap);
-
+				if( get_flags (wmh->flags, IconWindowIsChildHint) )
+					set_flags (clean->flags, AS_WMDockApp);
 			} else if (get_flags (wmh->flags, IconPixmapHint) && wmh->icon_pixmap != None)
 			{
 				clean->icon.pixmap = wmh->icon_pixmap;
@@ -969,7 +985,7 @@ static ASFlagType extwm_types_start_properties[][3] = {
 	{EXTWM_TypeNormal, AS_LayerNormal, 0},  
 	{EXTWM_TypeUtility, AS_LayerTop, 0}, 	
 	{EXTWM_TypeSplash, AS_LayerTop, AS_ShortLived },
-	{EXTWM_TypeASModule, AS_LayerService, AS_StartsSticky },
+	{EXTWM_TypeASModule, AS_LayerNormal, AS_StartsSticky },
 	{0, 0, 0}
 };
 static ASFlagsXref extwm_type_xref[] = {	   /*Flag              Set if Set,      Clear if Set,     Set if Clear,    Clear if Clear  */
@@ -1010,12 +1026,12 @@ merge_extwm_hints (ASHints * clean, ASRawHints * raw,
 
 	if (get_flags (what, HINT_NAME))
 	{
+		if (eh->visible_name)
+			add_name_to_list (clean->names, text_property2string (eh->visible_name), clean->names_encoding, AS_Text_UTF8);
 		if (eh->name)
 			add_name_to_list (clean->names, text_property2string (eh->name), clean->names_encoding, AS_Text_UTF8);
 		if (eh->icon_name)
 			clean->icon_name_idx = add_name_to_list (clean->names, text_property2string (eh->icon_name), clean->names_encoding, AS_Text_UTF8);
-		if (eh->visible_name)
-			add_name_to_list (clean->names, text_property2string (eh->visible_name), clean->names_encoding, AS_Text_UTF8);
 		if (eh->visible_icon_name)
 			clean->icon_name_idx = add_name_to_list (clean->names, text_property2string (eh->visible_icon_name), clean->names_encoding, AS_Text_UTF8);
 		clean->icon_name = (clean->icon_name_idx <0 )?NULL: clean->names[clean->icon_name_idx] ;
@@ -1051,7 +1067,9 @@ merge_extwm_hints (ASHints * clean, ASRawHints * raw,
 			for (i = 0; extwm_types_start_properties[i][0] != 0; i++)
 				if (get_flags (eh->flags, extwm_types_start_properties[i][0]))
 				{
-					status->layer = extwm_types_start_properties[i][1];
+					if( !get_flags (status->flags, AS_StartLayer) ||
+						status->layer < extwm_types_start_properties[i][1] ) 
+						status->layer = extwm_types_start_properties[i][1];
 					set_flags (status->flags, AS_StartLayer);
 					set_flags (status->flags, extwm_types_start_properties[i][2]);
 				}
@@ -1132,6 +1150,7 @@ merge_asdb_hints (ASHints * clean, ASRawHints * raw, ASDatabaseRecord * db_rec,
 		{STYLE_HANDLES, AS_Handles, 0, 0, AS_Handles},
 		{STYLE_FOCUS_ON_MAP, AS_FocusOnMap, 0, 0, AS_FocusOnMap},
 		{STYLE_LONG_LIVING, 0, AS_ShortLived, AS_ShortLived, 0},
+		{STYLE_IGNORE_CONFIG, AS_IgnoreConfigRequest, 0, 0, AS_IgnoreConfigRequest},
 		{0, 0, 0, 0, 0}
 	};
 
@@ -1364,7 +1383,7 @@ update_property_hints_manager (Window w, Atom property, ASSupportedHints * list,
 	if (handle_manager_property_update (w, property, &raw))
 	{
 		ASHints       clean;
-
+		memset( &clean, 0x00, sizeof(ASHints));
 		show_debug (__FILE__, __FUNCTION__, __LINE__, "property update handled");
 		if (property == _XA_WM_STATE)
 		{
@@ -1381,7 +1400,7 @@ update_property_hints_manager (Window w, Atom property, ASSupportedHints * list,
 			}
 			return changed;
 		}
-		if (hints && merge_hints (&raw, db, NULL, list, HINT_ANY, &clean) != NULL)
+		if (hints && merge_hints (&raw, db, NULL, list, HINT_ANY, &clean, w) != NULL)
 		{
 
 			show_debug (__FILE__, __FUNCTION__, __LINE__, "hints merged");
@@ -1420,8 +1439,11 @@ update_property_hints_manager (Window w, Atom property, ASSupportedHints * list,
 				hints->icon_name_idx = clean.icon_name_idx;
 				show_debug (__FILE__, __FUNCTION__, __LINE__, "names set");
 
-				hints->flags = clean.flags ;
-				hints->function_mask = clean.function_mask ;
+				/* Must not do that as it requires sugnificant changes in decorations and stuff : 
+				 * and should be done only when FollowTitleChanges is requested */
+				/* hints->flags = clean.flags ;
+				   hints->function_mask = clean.function_mask ;
+				 */
 			} else if (property == XA_WM_HINTS)
 			{
 
@@ -1532,7 +1554,7 @@ function2mask (int function)
  ****************************************************************************/
 
 void
-constrain_size (ASHints * hints, ASStatusHints * status, unsigned int max_width, unsigned int max_height)
+constrain_size (ASHints * hints, ASStatusHints * status, int max_width, int max_height)
 {
     int minWidth = 1, minHeight = 1;
     int xinc = 1, yinc = 1, delta;
@@ -1697,7 +1719,7 @@ translate_asgeometry (ScreenInfo * scr, ASGeometry * asg, int *px, int *py, unsi
 		} else if (get_flags (asg->flags, YNegative))
 			grav = SouthWestGravity;
 	}
-	if (get_flags (asg->flags, WidthValue))
+	if ( asg && get_flags (asg->flags, WidthValue))
 	{
 		width = asg->width;
 		if (pwidth)
@@ -1705,46 +1727,52 @@ translate_asgeometry (ScreenInfo * scr, ASGeometry * asg, int *px, int *py, unsi
 	} else if (pwidth)
 		width = *pwidth;
 
-	if (get_flags (asg->flags, HeightValue))
+	if (asg && get_flags (asg->flags, HeightValue))
 	{
 		height = asg->height;
 		if (pheight)
 			*pheight = height;
 	} else if (pheight)
 		height = *pheight;
-
-	if (get_flags (asg->flags, XValue) && px)
-	{
-		if (get_flags (asg->flags, XNegative))
+	if( asg )
+	{	
+		if (get_flags (asg->flags, XValue) && px)
 		{
-			if (asg->x <= 0)
-				*px = scr->MyDisplayWidth + asg->x;
-			else
-				*px = scr->MyDisplayWidth - asg->x;
-			*px -= width;
-		} else
-			*px = asg->x;
-	}
-	if (get_flags (asg->flags, YValue) && py)
-	{
-		if (get_flags (asg->flags, YNegative))
+			if (get_flags (asg->flags, XNegative))
+			{
+				if (asg->x <= 0)
+					*px = scr->MyDisplayWidth + asg->x;
+				else
+					*px = scr->MyDisplayWidth - asg->x;
+				*px -= width;
+			} else
+				*px = asg->x;
+		}
+		if (get_flags (asg->flags, YValue) && py)
 		{
-			if (asg->x <= 0)
-				*py = scr->MyDisplayHeight + asg->y;
-			else
-				*py = scr->MyDisplayHeight - asg->y;
-			*py -= height;
-		} else
-			*py = asg->y;
-	}
+			if (get_flags (asg->flags, YNegative))
+			{
+				if (asg->x <= 0)
+					*py = scr->MyDisplayHeight + asg->y;
+				else
+					*py = scr->MyDisplayHeight - asg->y;
+				*py -= height;
+			} else
+				*py = asg->y;
+		}
+	}else
+	{
+		if( px ) *px = 0 ;	
+		if( py ) *py = 0 ;
+	}	 
 
 	return grav;
 }
 
 int
-make_anchor_pos (ASStatusHints * status, int pos, unsigned int size, int vpos, int grav, int max_pos)
+make_anchor_pos (ASStatusHints * status, int pos, int size, int vpos, int grav, int max_pos)
 {											   /* anchor position is always in virtual coordinates */
-	unsigned int  bw = 0;
+	int  bw = 0;
 
 	if (get_flags (status->flags, AS_StartBorderWidth))
 		bw = status->border_width;
@@ -1862,7 +1890,7 @@ make_detach_pos (ASHints * hints, ASStatusHints * status, XRectangle *anchor, in
  */
 
 void
-status2anchor (XRectangle * anchor, ASHints * hints, ASStatusHints * status, unsigned int vwidth, unsigned int vheight)
+status2anchor (XRectangle * anchor, ASHints * hints, ASStatusHints * status, int vwidth, int vheight)
 {
 	if (get_flags (status->flags, AS_Size))
 	{
@@ -2030,7 +2058,7 @@ change_placement (ScreenInfo * scr, ASHints * hints, ASStatusHints * status, XPo
 }
 
 int
-calculate_viewport (int *pos, unsigned int size, unsigned int scr_vpos, unsigned int scr_size, int max_viewport)
+calculate_viewport (int *pos, int size, int scr_vpos, int scr_size, int max_viewport)
 {
 	int           viewport = -1;
 
