@@ -26,7 +26,10 @@
 
 #include <signal.h>
 #include <unistd.h>
+#include <sys/types.h>
+#include <regex.h>
 #include <stdlib.h>
+#include <math.h>
 
 #include "../../libAfterImage/afterimage.h"
 
@@ -74,6 +77,7 @@
 #define ARRANGE_Tile_Horizontally	(0x01<<18)
 #define ARRANGE_AllDesks                (0x01<<19)
 #define ARRANGE_WinlistSkip             (0x01<<20)
+#define ARRANGE_SmartTile                 (0x01<<21)
 
 struct ASArrangeState
 {
@@ -92,6 +96,8 @@ struct ASArrangeState
 
 	int tile_width, tile_height;
 
+	char *pattern;
+
 	ASBiDirList *clients_order;
 	   
 }ArrangeState;
@@ -295,7 +301,14 @@ main( int argc, char **argv )
 				if(! resize_touched )
 					set_flags(ArrangeState.flags, ARRANGE_Resize );
 			}
-			/* these applies to tiling only : */    
+			else if( mystrcasecmp( argv[i], "-smart") == 0)
+			{
+				set_flags(ArrangeState.flags, ARRANGE_SmartTile);
+			}else if( mystrcasecmp( argv[i], "-pattern") == 0 && i+1 <argc && argv[i+1] != NULL)
+			{
+				ArrangeState.pattern = argv[i+1];
+			}
+			/* these apply to tiling only : */    
 			else if( mystrcasecmp( argv[i], "-mn") == 0 && i+1 < argc )
 			{
 				/* Tiles up to \fIarg\fP windows in tile direction.  If more windows
@@ -361,7 +374,8 @@ GetBaseOptions (const char *filename)
 Bool
 window_is_suitable(ASWindowData *wd)
 {
-	
+	regex_t my_reg;
+        
         /* we do not want to arrange AfterSTep's modules */
 	if( get_flags( wd->flags, AS_Module))
 		return False;
@@ -408,6 +422,23 @@ window_is_suitable(ASWindowData *wd)
 	  )
 		return False;
 
+	/* If a pattern was specified, check if window matches*/
+	if( ArrangeState.pattern )
+	{		
+		if(regcomp( &my_reg, ArrangeState.pattern, REG_EXTENDED | REG_ICASE ) != 0)
+			return False;
+		
+		
+                /* If pattern doesn't match */
+		if( regexec( &my_reg, wd->window_name, 0, NULL, 0) )
+		{
+			regfree( &my_reg );
+			return False;
+		}
+		regfree( &my_reg );
+	}
+	
+	
 	/* Passed all tests. You're in. */
 	return True;
 }
@@ -565,8 +596,12 @@ tile_windows()
 		
         /* If number of elements per group was not set */
 	if(ArrangeState.count == 0)
-	  ArrangeState.count = n_windows; /*Put all elements in one group*/
-	
+	{
+		if( ! get_flags(ArrangeState.flags, ARRANGE_SmartTile) )
+			ArrangeState.count = n_windows; /*Put all elements in one group*/
+		else
+			ArrangeState.count = (int) sqrt(n_windows);
+	}
 	n_groups = n_windows / ArrangeState.count;
 	/* If not all windows fit in n_groups groups, an
 	 * extra group for remaining windows is needed.*/
