@@ -262,6 +262,7 @@ struct config main_config[] = {
 	{"CustomCursor"						, SetCustomCursor, (char **)0, (int *)0},
 	{"Cursor"							, SetCursor, (char **)0, (int *)0},
     /***********************************/
+    {"IconsGrowVertically", SetLookFlag, (char **)IconsGrowVertically, (int *) 0},
 	{"MenuPinOn"						, assign_string, &MenuPinOn, (int *)0},    /* menu pin */
     {"MArrowPixmap"						, assign_pixmap, (char **)&TmpLook.MenuArrow, (int *)0},   /* menu arrow */
     {"TitlebarNoPush"					, SetLookFlag, (char **)TitlebarNoPush, NULL},
@@ -613,11 +614,13 @@ merge_old_look_variables (MyLook *look)
 void
 InitFeel (ASFeel *feel, Bool free_resources)
 {
-    if (free_resources && feel)
-		destroy_asfeel( feel, True );
-    feel->magic = MAGIC_ASFEEL ;
-	init_asfeel( feel );
-
+	if( feel ) 
+	{	
+    	if (free_resources)
+			destroy_asfeel( feel, True );
+    	feel->magic = MAGIC_ASFEEL ;
+		init_asfeel( feel );
+	}
 }
 
 void 
@@ -1531,7 +1534,8 @@ LoadASConfig (int thisdesktop, ASFlagType what)
                 display_progress( True, "LOOK configuration file cannot be found!");
                 clear_flags(what, PARSE_LOOK_CONFIG);
             }
-        }
+        	UpdateGtkRC();
+		}
         if (get_flags(what, PARSE_FEEL_CONFIG))
 		{
             if( (const_configfile = get_session_file (Session, thisdesktop, F_CHANGE_FEEL, False) ) != NULL )
@@ -1627,6 +1631,7 @@ LoadASConfig (int thisdesktop, ASFlagType what)
         show_progress("AfterStep configuration loaded from \"%s\" ...", Session->overriding_file);
         display_progress( True, "AfterStep configuration loaded from \"%s\".", Session->overriding_file);
         what = PARSE_EVERYTHING ;
+		UpdateGtkRC();
     }
 
 	/* let's free the memory used for parsing */
