@@ -1120,9 +1120,6 @@ Bool place_aswindow( ASWindow *asw )
                      asw->status->width, asw->status->height, asw->status->x, asw->status->y,
                      asw->anchor.width, asw->anchor.height, asw->anchor.x, asw->anchor.y );
 
-    if( ASWIN_GET_FLAGS(asw, AS_MaximizedX|AS_MaximizedY ) )
-        return place_aswindow_in_windowbox( asw, Scr.Feel.default_window_box, ASP_UseBackupStrategy, True );
-
     if( asw->hints->windowbox_name )
     {
         aswbox = find_window_box( &(Scr.Feel), asw->hints->windowbox_name );
@@ -1136,9 +1133,9 @@ Bool place_aswindow( ASWindow *asw )
 
     if( aswbox == NULL )
     {
-        int i = Scr.Feel.window_boxes_num;
+        int i;
         aswbox = &(Scr.Feel.window_boxes[0]);
-        while( --i >= 0 )
+        for( i = 0 ; i < Scr.Feel.window_boxes_num ; ++i )
         {
 			LOCAL_DEBUG_OUT("window_box \"%s\": main_strategy = %d, backup_strategy = %d", 
 		   					aswbox[i].name, aswbox[i].main_strategy, aswbox[i].backup_strategy);
@@ -1152,7 +1149,18 @@ Bool place_aswindow( ASWindow *asw )
             if( aswbox[i].min_height > asw->status->height || (aswbox[i].max_height > 0 && aswbox[i].max_height < asw->status->height) )
                 continue;
 
-            if( place_aswindow_in_windowbox( asw, &(aswbox[i]), ASP_UseMainStrategy , False ))
+		    if( ASWIN_GET_FLAGS(asw, AS_MaximizedX|AS_MaximizedY ) )
+			{
+	            if( aswbox[i].area.x > asw->status->x+(int)(asw->status->width) || 
+					aswbox[i].area.y > asw->status->y+(int)(asw->status->height)||
+					aswbox[i].area.x+(int)aswbox[i].area.width < asw->status->x ||
+					aswbox[i].area.y+(int)aswbox[i].area.height < asw->status->y )
+    	            continue;
+			}	 
+
+		    if( ASWIN_GET_FLAGS(asw, AS_MaximizedX|AS_MaximizedY ) )
+        		return place_aswindow_in_windowbox( asw, &(aswbox[i]), ASP_UseBackupStrategy, True );
+			else if( place_aswindow_in_windowbox( asw, &(aswbox[i]), ASP_UseMainStrategy , False ))
                 return True;
         }
     }
@@ -1265,6 +1273,8 @@ void obey_avoid_cover(ASWindow *asw, ASStatusHints *tmp_status, XRectangle *tmp_
 	    ASWindowBox aswbox ;
         int selected_x = 0 ;
         int selected_y = 0 ;
+		int left = Scr.Vx, right = Scr.Vx+Scr.MyDisplayWidth ;
+		int top = Scr.Vy, bottom = Scr.Vy+Scr.MyDisplayHeight ;
 
         /* we need to move all the res of the window out of the area occupied by us */
 		LOCAL_DEBUG_OUT( "status = %dx%d%+d%+d, layer = %d", asw->status->width, asw->status->height, asw->status->x, asw->status->y, ASWIN_LAYER(asw) );
@@ -1274,10 +1284,28 @@ void obey_avoid_cover(ASWindow *asw, ASStatusHints *tmp_status, XRectangle *tmp_
      *   if all fails we apply backup strategy of the default windowbox
      */
         aswbox.name = mystrdup("default");
+		if( !ASWIN_GET_FLAGS(asw, AS_Sticky))
+		{
+			if( asw->status->x < 0 )
+				left = 0 ; 
+			if( asw->status->x+(int)asw->status->width >= Scr.MyDisplayWidth )		   
+				right = Scr.VxMax + Scr.MyDisplayWidth ; 
+			if( asw->status->y < 0 )
+				top = 0 ; 
+			if( asw->status->y+(int)asw->status->height >= Scr.MyDisplayHeight )		   
+				bottom = Scr.VyMax + Scr.MyDisplayHeight ; 
+		}	 
+#if 0
 		aswbox.area.x = Scr.Vx;
 		aswbox.area.y = Scr.Vy ;
         aswbox.area.width = Scr.MyDisplayWidth ;
         aswbox.area.height = Scr.MyDisplayHeight ;
+#else
+		aswbox.area.x = left;
+		aswbox.area.y = top;
+        aswbox.area.width = right - left ;
+        aswbox.area.height = bottom - top ;
+#endif
         aswbox.main_strategy = ASP_Manual ;
         aswbox.backup_strategy = ASP_Manual ;
         /* we should enforce this one : */
